<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_ImportMembers
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_ImportMembers extends Moc10_Form
{

    /**
     * Form template
     * @var string
     */
    protected $_template = null;

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('plugin' => null,
                                   'site_id' => null,
                                   'section_id' => null,
                                   'csv_file' => null,
                                   'send_creds' => null);

    /**
     * Initialization method for the import members form.
     *
     * @param  array $post
     * @param  string $fle_nme
     * @return void
     */
    public function init($post = null, $fle_nme = null)
    {

        $lang = new Phire_Language();

        $this->_setFields($post, $fle_nme);
        $this->_setTemplates();

        $this->setAttributes('id', 'editMemberForm');
        $this->setAttributes('enctype', 'multipart/form-data');

        // Create the 'site_id' form element.
        $site_id = new Moc10_Form_Element_Select('site_id', Phire_Sites::getAllowedSites(), $this->_postFields['site_id']);
        $site_id->setLabel($lang->__('Import to Site:'));

        $brws = new Moc10_Session_Browser();
        $fileClass = ($brws->browser == 'MSIE') ? 'fileInputIE' : 'fileInput';

        // Create the 'csv_file' form element.
        $csv_file = new Moc10_Form_Element('file', 'csv_file', $this->_postFields['csv_file']);
        $csv_file->setLabel($lang->__('CSV File:'));
        $csv_file->setAttributes('size', '40');
        $csv_file->setAttributes('class', $fileClass);
        $csv_file->setRequired(true);

        // Create the 'send_creds' form element.
        $send_creds = new Moc10_Form_Element_Checkbox('send_creds', array('send_creds' => $lang->__('Send credentials to members?')), $this->_postFields['send_creds']);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('IMPORT'));
        $submit->setAttributes('class', 'submitBtn');
        $submit->setAttributes('style', 'float: left;');

        // Set the form template and add the form element objects to the form.
        $this->setTemplate($this->_template);
        $this->addElements(array($site_id, $csv_file, $send_creds, $submit));

    }

    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {

        $lang = new Phire_Language();
        $back = $lang->__('Back');
        $imp_mbrs = $lang->__('Import Members');
        $upload_msg = wordwrap($lang->__('You can upload a CSV file to import a list of members. However, that CSV file must be in a similar format to the CSV template example for the data to be imported correctly. Click the link above to download the CSV template example.'), 80, "<br />\n");
        $sending = wordwrap($lang->__("Sending the credentials to the members requires both the server's PHP mail function and SMTP mail agent to be configured correctly."), 80, "<br />\n");
        $cancel = $lang->__('CANCEL');

        if (!is_null($this->_postFields['plugin'])) {
            $plugin = "<input type=\"hidden\" name=\"plugin\" value=\"{$this->_postFields['plugin']}\" />";
            $plg_lnk = BASE_PATH . CONTENT_PATH . "/extensions/plugins/{$this->_postFields['plugin']}/?sys_path=" . BASE_PATH . SYS_PATH;
            $plg_cancel = "&plugin={$this->_postFields['plugin']}";
        } else {
            $plugin = null;
            $plg_lnk = './members.php';
            $plg_cancel = null;
        }

        // Define the main form template.
        $this->_template = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="{$plg_lnk}">{$back}</a> <span class="grayPad">|</span> <a class="orangeLink" href="../core/misc/members-import-template.csv">Download CSV Template</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader">
                    <td class="grayHeader">
                        <strong style="padding-left: 25px;">{$imp_mbrs}</strong>
                    </td>
                </tr>
                <tr>
                    <td style="padding: 15px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td class="textTopRight">
                                    &nbsp;
                                </td>
                                <td>
                                    <p style="font-size: 0.9em;">
                                        {$upload_msg}
                                    </p>
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{site_id_label}]
                                </td>
                                <td>
                                    [{site_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{csv_file_label}]
                                </td>
                                <td>
                                    [{csv_file}]
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    [{send_creds}]
                                    <em style="font-size: 0.85em;">{$sending}</em>
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    [{submit}] <a style="float: left; margin: 0 0 0 10px; padding-top: 6px; height: 19px; font-size: 0.825em;" class="submitGrayBtn" href="../core/process/import.members.php?action=cancel{$plg_cancel}">{$cancel}</a> {$plugin}
                                </td>
                            </tr>
                        </table>
                    </td>
                </tr>
            </table>
FORMTEMP;

    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @param  string $fle_nme
     * @return void
     */
    protected function _setFields($post = null, $fle_nme = null)
    {

        if (!is_null($post)) {
            foreach ($post as $key => $value) {
                if (array_key_exists($key, $this->_postFields)) {
                    $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                }
            }
            $this->_postFields['csv_file'] = $fle_nme;
        }

    }

}
