<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Tag
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Tag
 *
 * @category   Phire
 * @package    Phire_Tag
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Tag extends Phire_Template
{

    /**
     * Tag id
     * @var tag
     */
    public $id = null;

    /**
     * Tag name
     * @var tag
     */
    public $tag = null;

    /**
     * Site object
     * @var Phire_Table_Site
     */
    protected $_site = null;

    /**
     * Constructor
     *
     * Instantiate the tag object.
     *
     * @param  string $url
     * @return void
     */
    public function __construct($url)
    {

        parent::__construct();
        $this->_tmpl = Phire_Parser::getParser($this->_tmpl, $url)->getContent();

        // Get the site information.
        $this->_site = new Phire_Table_Sites();
        $this->_site->getSite();

        $this->setContent('[{page_charset}]', $this->_site->charset);
        $this->setContent('[{page_author}]', Moc10_String::setString($this->_site->default_author)->strip()->html());
        $this->setContent('[{page_keywords}]', Moc10_String::setString($this->_site->default_keywords)->strip()->html());
        $this->setContent('[{page_desc}]', Moc10_String::setString($this->_site->default_desc)->strip()->html());
        $this->setContent('[{page_robots}]', $this->_site->robots);
        $this->setContent('[{site_domain}]', $this->_site->site_domain);
        $this->setContent('[{site_tags}]', Phire_TagCloud::render($this->_site->site_id));
        $this->setContent('[{base_path}]', BASE_PATH);
        $this->setContent('[{sys_path}]', SYS_PATH);
        $this->setContent('[{content_path}]', CONTENT_PATH);

        // Get tag data.
        $urlParts = Moc10_String::setString($url)->split('/');
        $this->tag = (isset($urlParts[2]) ? $urlParts[2] : null);

        $tag = new Phire_Table_Tags();
        $tag->findBy('tag', $this->tag);
        $this->id = (isset($tag->tag_id) ? $tag->tag_id : null);

    }

    /**
     * Initialize the tag template.
     *
     * @return void
     */
    public function init()
    {

        $lang = new Phire_Language();
        $sess = Moc10_Session::getInstance();

        // If no tag is found, display error.
        if (is_null($this->id) || is_null($this->tag)) {

            $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $lang->__('Tag') . " > " . $lang->__('Error'))->strip()->html());
            $this->setContent('[{page_sub_title}]', $lang->__('Tag') . " &gt; " . $lang->__('Error'));
            $this->setContent('[{page_content}]', "<!-- Tag Results Begin Here //-->\n        <div id=\"tagContent\">\n            <p><strong>" . $lang->__('That tag was not found.') . "</strong></p>\n        </div>\n<!-- Tag Results End Here //-->");

        // Else, perform the tag search.
        } else {

            // Format the tag results title.
            $this->setContent('[{page_title}]', Moc10_String::setString($this->_site->default_title . $this->_site->title_separator . $lang->__('Tag Results') . ' > "' . $this->tag . '"')->strip()->html());
            $this->setContent('[{page_sub_title}]', $lang->__('Tag Results') . ' &gt; "' . $this->tag . '"');
            $tagResults = "<!-- Tag Results Begin Here //-->\n";

            // Get tag results.
            $pages = new Phire_Table_Pages();

            if (isset($sess->user_id) || isset($sess->member_id)) {
                $pages->execute("SELECT * FROM " . DB_PREFIX . "pages WHERE (site_id = '" . $this->_site->site_id . "' AND published = 'Yes') AND (page_tags LIKE '%" . $this->id . "%')");
            } else {
                $pages->execute("SELECT * FROM " . DB_PREFIX . "pages WHERE page_access = 'Public' AND (site_id = '" . $this->_site->site_id . "' AND published = 'Yes') AND (page_tags LIKE '%" . $this->id . "%')");
            }

            // If found, format the tag results.
            if (isset($pages->rows[0])) {

                $tagResults .= "        <div id=\"tagContent\">\n";

                foreach ($pages->rows as $page) {

                    // Set page title and URL.
                    $page_url = BASE_PATH . $page->page_url;
                    $page_title = Moc10_String::setString($page->page_title)->strip();

                    // Create page summary, stripping away JS tags and content, normal HTML tags and white space.
                    $page_content = Moc10_String::setString($page->page_content)->replace('[{page_sub_title}]', (string)Moc10_String::setString($page->page_title)->strip()->html())->preg('/<script(.*?)<\/script>/si', '')->striptags()->preg('/\[\{(.?)*\}\]/', '')->preg('/\s\s+/', '');

                    $summary = '...' . $page_content->sub(0, 300) . '...';

                    $tagResults .= "            <div class=\"tagResult\">\n                <a class=\"tagTitle\" href=\"{$page_url}\">{$page_title}</a>\n                {$summary}\n            </div>\n";

                }

                $tagResults .= "        </div>\n<!-- Tag Results End Here //-->";

            // Else format empty set.
            } else {

                $tagResults .= "        <div id=\"tagContent\">\n            <p><strong>" . $lang->__('Sorry, no tags where found.') . "</strong></p>\n        </div>\n<!-- Tag Results End Here //-->";

            }

            $this->setContent('[{page_content}]', $tagResults);

        }

    }

}
