<?php

/**
 * Phire Add Files
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

set_time_limit(0);
require_once '../../bootstrap.php';

try {

    // Retrieve session and check if the add file action has been cancelled, clearing out any related session data.
    $sess = Moc10_Session::getInstance();

    if ((isset($_GET['action'])) && ($_GET['action'] == 'cancel')) {

        unset($sess->file_error);
        unset($sess->add_files_form);

        if (isset($_GET['plugin'])) {
            header('Location: ' . BASE_PATH . CONTENT_PATH . '/extensions/plugins/' . $_GET['plugin'] . '/?sys_path=' . BASE_PATH . SYS_PATH);
        } else {
            header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_GET['mobile'])) ? 'mobile/' : '') . 'assets/files.php');
        }

    // Else, get the POST data and validate the form.
    } else {

        unset($sess->add_files_form);
        unset($sess->file_error);

        $fle_nme = (isset($_FILES['file_name_1']['name']) ? $_FILES['file_name_1']['name'] : null);

        $form = new Phire_Form_AddFile(BASE_PATH . SYS_PATH . '/core/process/add.files.php', 'post', '        ');
        $form->init($_POST, $fle_nme);

        // If the form is valid, process the new file(s).
        if ($form->isValid()) {

            // Get the file extensions and types.
            $keys = array();
            $exts = array();
            foreach ($_FILES as $key => $value) {
                if ((strpos($key, 'file_name_') !== false) && ($_FILES[$key]['name'] != '')) {
                    $keys[] = substr($key, (strrpos($key, '_') + 1));
                    $path_parts = pathinfo($_FILES[$key]['name']);
                    $exts[] = (isset($path_parts['extension'])) ? $path_parts['extension'] : 'NO_EXT';
                }
            }

            // Check the site for any file format restrictions.
            $site = new Phire_Table_Sites();
            $site->findById($_POST['site_id']);
            if ($site->allowed_file_formats != 'any') {
                $allowed_types = explode('|', $site->allowed_file_formats);
                foreach ($exts as $value) {
                    if (!in_array(strtolower($value), $allowed_types)) {
                        $sess->file_error = "<div class=\"error\">" . $lang->__('The %1 file format is not allowed.', strtoupper($value)) . "</div>\n";
                    }
                }
            }

            // If a file is passed that isn't allowed, return with the error.
            if (isset($sess->file_error)) {

                $sess->add_files_form = $form;
                header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/add-files.php');

            // Else, finish processing the file(s).
            } else {

                unset($sess->add_files_form);
                unset($sess->file_error);

                // Check the file size against the max allowed file size.
                $file_max_size = null;

                if (strpos($site->file_max_size, 'MB') !== false) {
                    $file_max_size = str_replace(' MB', '000000', $site->file_max_size);
                } else {
                    $file_max_size = str_replace(' KB', '000', $site->file_max_size);
                }

                try {

                    foreach ($keys as $value) {

                        // Check for duplicate files and rename accordingly.
                        $newfile = $_FILES['file_name_' . $value]['name'];
                        $path_parts = pathinfo($newfile);
                        $orgfile = $path_parts['filename'];
                        $ext = (isset($path_parts['extension'])) ? $path_parts['extension'] : 'NO_EXT';
                        $i = 1;

                        while (file_exists($site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/files/' . $newfile)) {
                            $newfile = $orgfile . '_' . $i . '.' . $ext;
                            $i++;
                        }

                        // If a unique file name is confirmed, process the new file upload.
                        $file = new Moc10_File_Upload($_FILES['file_name_' . $value]['tmp_name'], $site->site_docroot . BASE_PATH . CONTENT_PATH . '/assets/files/' . $newfile, $file_max_size);

                        $fle_title = str_replace('-', ' ', str_replace('_', ' ', substr($newfile, 0, strrpos($newfile, '.'))));

                        // Add the new file in the system.
                        $fields = array('site_id' => $_POST['site_id'],
                                        'user_id' => $sess->user_id,
                                        'section_id' => $_POST['section_id'],
                                        'file_name' => $newfile,
                                        'file_title' => (($_POST['file_title_' . $value] != '') ? $_POST['file_title_' . $value] : $fle_title),
                                        'file_desc' => (($_POST['file_desc_' . $value] != '') ? $_POST['file_desc_' . $value] : ''),
                                        'file_updated' => date('Y-m-d H:i:s'));
                        $fle = new Phire_Table_Files($fields);
                        $fle->save();
                    }

                    // Return.
                    if ((isset($_POST['plugin'])) && (!is_null($_POST['plugin']))) {
                        header('Location: ' . BASE_PATH . CONTENT_PATH . '/extensions/plugins/' . $_POST['plugin'] .'/?action=saved&sys_path=' . BASE_PATH . SYS_PATH);
                    } else {
                        header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/files.php?action=saved');
                    }

                } catch (Exception $e) {

                    $sess->file_error = "<div class=\"error\">" . $e->getMessage() . "</div>\n";
                    $sess->add_files_form = $form;
                    header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/add-files.php');

                }

            }

        // Else, set the form into a session variable and return.
        } else {

            $sess->add_files_form = $form;
             header('Location: ' . BASE_PATH . SYS_PATH . '/' . ((isset($_POST['mobile'])) ? 'mobile/' : '') . 'assets/add-files.php');

        }

    }

// Else throw a exception/error.
} catch (Exception $e) {

    include_once 'init.php';
    include_once '../includes/error.header.php';
    print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 0 0;\">" . $e->getMessage() . "</p>\n");
    include_once '../includes/footer.php';

}

?>
