<?php

/**
 * Phire Server Check
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

require_once dirname(__FILE__) . '/config.check.php';

// Get server and system values for display in the footer.
$lang = new Phire_Language();
$server= new Moc10_Session_Server();
$sys = array();
$system = new Phire_Table_Config();

$sys['system_version'] = 'Phire CMS v ' . $system->settings['system_version'];
$sys['server_software'] = $system->settings['server_os'] . ' / ';
$sys['server_software'] .= (stripos($system->settings['server_software'], 'iis') !== false) ? 'IIS' : 'Apache';
$sys['mysql_version'] = 'MySQL v' . $system->settings['mysql_version'];
$sys['php_version'] = 'PHP v' . $system->settings['php_version'];
$sys['installed_on'] = $lang->__('Installed:') . ' ' . date('M j, Y', strtotime($system->settings['installed_on']));
$sys['updated_on'] = $lang->__('Updated:') . (($system->settings['updated_on'] == '0000-00-00 00:00:00') ? ' ' . $lang->__('Never') : ' ' . date('M j, Y', strtotime($system->settings['updated_on'])));

if ((stripos($sys['server_software'], $server->server) !== false) && (!is_null($server->serverVersion)) && ($server->serverVersion != 'Unknown')) {
    $sys['server_software'] = $sys['server_software'] . ' ' . $server->serverVersion;
}

$sess->sys = $sys;

// Set the appropriate sync error message.
$sess->sync_error = null;

if ($sess->access == 'Admin') {
    $sync_error_msg = "        <span class=\"error\">" . $lang->__('There is a sync error with the software on the server.') . "</span> " . $lang->__('This could be due to a software upgrade or system transfer.') . "<br />" . $lang->__('%1Click here%2 to review the current system configuration or %3click here%4 to resolve the issue.', array("<a href=\"" . BASE_PATH . SYS_PATH . "/system/configuration.php\">", "</a>", "<a href=\"" . BASE_PATH . SYS_PATH . "/system/resync.php\">" , "</a>")) . "<br />\n";
} else {
    $sync_error_msg = "        <span class=\"error\">" . $lang->__('There is a sync error with the software on the server.') . "</span> " . $lang->__('This could be due to a software upgrade or system transfer. Please contact the system administrator to resolve this issue.') . "<br />\n";
}

// Get current server OS and software info.
$server = new Moc10_Session_Server();
$mysqlVersionAry = explode('-', Moc10_Db::getInstance()->interface->version());
$system_docroot = $_SERVER['DOCUMENT_ROOT'];
$os = ($server->distro != 'Unknown') ? $server->os . ' (' . $server->distro . ')' : $server->os;

// Test system and server configuration settings to determine if there has been a sync issue, setting the error message if applicable.
if ($system->settings['system_docroot'] != $system_docroot) {
    $sess->sync_error = $sync_error_msg;
}
if ($system->settings['server_os'] != $os) {
    $sess->sync_error = $sync_error_msg;
}
if ($system->settings['server_software'] != $server->software) {
    $sess->sync_error = $sync_error_msg;
}
if ($system->settings['mysql_version'] != trim(str_ireplace('mysql', '', $mysqlVersionAry[0]))) {
    $sess->sync_error = $sync_error_msg;
}
if ($system->settings['php_version'] != $server->php) {
    $sess->sync_error = $sync_error_msg;
}

?>