<?php

/**
 * Phire Update Config
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

require_once '../../bootstrap.php';

// Start a session and create a new DB config object.
$sess = Moc10_Session::getInstance();
$config = new Phire_Table_Config();

try {

    // If IP screening has been turned on.
    if ($_POST['ip_screening'] == 'On') {

        // Verify at least one allowed or blocked value has been passed.
        if (($_POST['ip_allowed'] == '') && ($_POST['ip_blocked'] == '')) {

            $sess->ip_error = "<span class=\"error\">You must at least enter one IP address to allow or one IP address to block.</span>";
            header('Location: ' . BASE_PATH . SYS_PATH . '/system/configuration.php');

        // Verify the passed IP addresses/groups.
        } else {

            unset($sess->ip_error);
            unset($sess->ip_allowed_error);
            unset($sess->ip_allowed_value);
            unset($sess->ip_blocked_error);
            unset($sess->ip_blocked_value);

            // Set the IP allowed array.
            if (strpos($_POST['ip_allowed'], ',') !== false) {
                $ip_allowed = Moc10_String::setString($_POST['ip_allowed'])->replace(', ', ',')->split(',');
            } else {
                $ip_allowed = array($_POST['ip_allowed']);
            }

            // Set the IP blocked array.
            if (strpos($_POST['ip_blocked'], ',') !== false) {
                $ip_blocked = Moc10_String::setString($_POST['ip_blocked'])->replace(', ', ',')->split(',');
            } else {
                $ip_blocked = array($_POST['ip_blocked']);
            }

            // Clean the allowed IP address values.
            foreach ($ip_allowed as $key => $value) {
                $ip_allowed[$key] = trim($value);
            }

            // Clean the blocked IP address values.
            foreach ($ip_blocked as $key => $value) {
                $ip_blocked[$key] = trim($value);
            }

            // Evaluate each allowed IP address and verify its validity.
            if (isset($ip_allowed[0]) && ($ip_allowed[0] != '')) {
                foreach ($ip_allowed as $value) {
                    $ip = new Moc10_String($value);
                    // Check wildcard subnet groups.
                    if ($ip->pos('*') !== false) {
                        if (($ip->length() - 2) == $ip->pos('.*')) {
                            $subnet = (string)$ip->sub(0, $ip->pos('.*'));
                            if (preg_match('/\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b/', $subnet) == 0) {
                                $sess->ip_allowed_error = "<span class=\"error\">" . $lang->__("One or more of the 'allowed' IP addresses was not valid.") . "</span>";
                                $sess->ip_allowed_value = $_POST['ip_allowed'];
                                $sess->ip_blocked_value = $_POST['ip_blocked'];
                            }
                        } else {
                            $sess->ip_allowed_error = "<span class=\"error\">" . $lang->__("One or more of the 'allowed' IP addresses was not valid.") . "</span>";
                            $sess->ip_allowed_value = $_POST['ip_allowed'];
                            $sess->ip_blocked_value = $_POST['ip_blocked'];
                        }
                    // Check regular IP addresses.
                    } else if (preg_match('/\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b/', (string)$ip) == 0) {
                        $sess->ip_allowed_error = "<span class=\"error\">" . $lang->__("One or more of the 'allowed' IP addresses was not valid.") . "</span>";
                        $sess->ip_allowed_value = $_POST['ip_allowed'];
                        $sess->ip_blocked_value = $_POST['ip_blocked'];
                    }
                }
            }

            // Evaluate each blocked IP address and verify its validity.
            if (isset($ip_blocked[0]) && ($ip_blocked[0] != '')) {
                foreach ($ip_blocked as $value) {
                    $ip = new Moc10_String($value);
                    if ($ip->pos('*') !== false) {
                        if (($ip->length() - 2) == $ip->pos('.*')) {
                            $subnet = (string)$ip->sub(0, $ip->pos('.*'));
                            if (preg_match('/\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b/', $subnet) == 0) {
                                $sess->ip_blocked_error = "<span class=\"error\">" . $lang->__("One or more of the 'blocked' IP addresses was not valid.") . "</span>";
                                $sess->ip_allowed_value = $_POST['ip_allowed'];
                                $sess->ip_blocked_value = $_POST['ip_blocked'];
                            } else if (in_array($value, $ip_allowed)) {
                                $sess->ip_blocked_error = "<span class=\"error\">" . $lang->__("IP Conflict. One or more of the 'blocked' IP addresses is also listed as an 'allowed' IP address.") . "</span>";
                                $sess->ip_allowed_value = $_POST['ip_allowed'];
                                $sess->ip_blocked_value = $_POST['ip_blocked'];
                            }
                        } else {
                            $sess->ip_blocked_error = "<span class=\"error\">" . $lang->__("One or more of the 'blocked' IP addresses was not valid.") . "</span>";
                            $sess->ip_allowed_value = $_POST['ip_allowed'];
                            $sess->ip_blocked_value = $_POST['ip_blocked'];
                        }
                    // Check regular IP addresses.
                    } else if (preg_match('/\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b/', (string)$ip) == 0) {
                        $sess->ip_blocked_error = "<span class=\"error\">" . $lang->__("One or more of the 'blocked' IP addresses was not valid.") . "</span>";
                        $sess->ip_allowed_value = $_POST['ip_allowed'];
                        $sess->ip_blocked_value = $_POST['ip_blocked'];
                    // Check for duplicate IP addresses in the allowed and blocked fields.
                    } else if (in_array((string)$ip, $ip_allowed)) {
                        $sess->ip_blocked_error = "<span class=\"error\">" . $lang->__("IP Conflict. One or more of the 'blocked' IP addresses is also listed as an 'allowed' IP address.") . "</span>";
                        $sess->ip_allowed_value = $_POST['ip_allowed'];
                        $sess->ip_blocked_value = $_POST['ip_blocked'];
                    }
                }
            }

            // If an IP error was found, return to the configuration page.
            if (isset($sess->ip_allowed_error) || isset($sess->ip_blocked_error)) {

                header('Location: ' . BASE_PATH . SYS_PATH . '/system/configuration.php');

            // Else, clear error messages and values and set and store the new system configuration values.
            } else {

                unset($sess->ip_allowed_error);
                unset($sess->ip_allowed_value);
                unset($sess->ip_blocked_error);
                unset($sess->ip_blocked_value);

                $config->findById('ip_screening');
                $config->value = $_POST['ip_screening'];
                $config->save();

                $config->findById('ip_allowed');
                $config->value = implode(',', array_unique($ip_allowed));
                $config->save();

                $config->findById('ip_blocked');
                $config->value = implode(',', array_unique($ip_blocked));
                $config->save();

            }

        }

    // Else, turn off IP screening, clear the values and set the rest of the system configuration.
    } else {

        $config->findById('ip_screening');
        $config->value = $_POST['ip_screening'];
        $config->save();

        $config->findById('ip_allowed');
        $config->value = '';
        $config->save();

        $config->findById('ip_blocked');
        $config->value = '';
        $config->save();

    }

    $config->findById('use_ssl_connection');
    $config->value = $_POST['use_ssl_connection'];
    $config->save();

    $config->findById('mobile_access_allowed');
    $config->value = $_POST['mobile_access_allowed'];
    $config->save();

    $config->findById('multiple_sessions_allowed');
    $config->value = $_POST['multiple_sessions_allowed'];
    $config->save();

    $config->findById('user_verification');
    $config->value = $_POST['user_verification'];
    $config->save();

    $config->findById('user_password_encoding');

    // If the user password encoding setting has been turned on, encode all user passwords.
    if (($config->value == 'Off') && ($_POST['user_password_encoding'] != 'Off')) {

        $users = new Phire_Table_Users();
        $users->findAll();

        foreach ($users->rows as $user) {
            $usr = new Phire_Table_Users();
            $usr->findById($user->user_id);
            $usr->password = ($_POST['user_password_encoding'] == 'SHA1') ? sha1($usr->password) : md5($usr->password);
            $usr->save();
        }

    // Else, if encoding is turned off, reset passwords to a random string and send notification email to users.
    } else if (($config->value != 'Off') && ($_POST['user_password_encoding'] != $config->value)) {

        $users = new Phire_Table_Users();
        $users->findAll();

        // Build and send the notification email(s) to the user(s).
        $rcpts = array();
        $message = "[{name}],\n\n" . $lang->__('Due to security measures enforced by the system admin, the password to your user account for the Phire CMS has been changed. Your new credentials for the Phire CMS are:') . "\n\n" . $lang->__('Username:') . " [{username}]\n" . $lang->__('Password:') . " [{password}]\n\n" . $lang->__("You can log in at the link below and change your password or manage your account by clicking on the 'My Account' link at the top right.") . "\n[{login_link}]\n\n" . $lang->__('Thank You,') . "\n\n" . $lang->__('The Phire CMS Team.') . "\n\n";

        foreach ($users->rows as $user) {
            $new_password = strtolower(Moc10_String::setString('')->random(8));
            $usr = new Phire_Table_Users();
            $usr->findById($user->user_id);
            if ($_POST['user_password_encoding'] == 'MD5') {
                $pass = md5($new_password);
            } else if ($_POST['user_password_encoding'] == 'SHA1') {
                $pass = sha1($new_password);
            } else {
                $pass = $new_password;
            }
            $usr->password = $pass;
            $usr->save();

            $rcpts[] = array('name' =>  $usr->fname . ' ' . $usr->lname,
                             'email' => $usr->email,
                             'username' => $usr->username,
                             'password' => $new_password,
                             'login_link' => 'http://' . $_SERVER['HTTP_HOST'] . BASE_PATH . SYS_PATH . '/');
        }

        $noreply = 'noreply@' . ((stripos($_SERVER['HTTP_HOST'], 'www.') !== false) ? str_replace('www.', '', $_SERVER['HTTP_HOST']) : $_SERVER['HTTP_HOST']);

        $mail = new Moc10_Mail($rcpts, null, $lang->__('Phire CMS User Account Modified - Password Reset'));
        $mail->setHeaders(array('From' => array($noreply, $noreply),
                                'Reply-To' => array($noreply, $noreply)));


        $mail->setText($message);
        $mail->init();
        $mail->send();

    }

    $config->value = $_POST['user_password_encoding'];
    $config->save();

    $config->findById('table_optimization');
    $config->value = $_POST['table_optimization'];
    $config->save();

    $config->findById('optimization_period');
    $config->value = ($_POST['table_optimization'] == 'On') ? $_POST['optimization_period'] : null;
    $config->save();

    $config->findById('failed_login_attempts');
    $config->value = (is_numeric($_POST['failed_login_attempts'])) ? round(abs($_POST['failed_login_attempts'])) : '0';
    $config->save();

    $config->findById('system_notification');
    $config->value = (isset($_POST['system_notification'])) ? implode('|', $_POST['system_notification']) : '';
    $config->save();

    unset($sess->ip_filter_error);
    unset($sess->ip_filter_value);

    // Set the IP filter array.
    if (strpos($_POST['system_notification_filter'], ',') !== false) {
        $ip_filter = Moc10_String::setString($_POST['system_notification_filter'])->replace(', ', ',')->split(',');
    } else {
        $ip_filter = array($_POST['system_notification_filter']);
    }
    // Clean the filtered IP address values.
    foreach ($ip_filter as $key => $value) {
        $ip_filter[$key] = trim($value);
    }

    // Evaluate each allowed IP address and verify its validity.
    if (isset($ip_filter[0]) && ($ip_filter[0] != '')) {
        foreach ($ip_filter as $value) {
            $ip = new Moc10_String($value);
            // Check wildcard subnet groups.
            if ($ip->pos('*') !== false) {
                if (($ip->length() - 2) == $ip->pos('.*')) {
                    $subnet = (string)$ip->sub(0, $ip->pos('.*'));
                    if (preg_match('/\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b/', $subnet) == 0) {
                        $sess->ip_filter_error = "<span class=\"error\">" . $lang->__("One or more of the 'filtered' IP addresses was not valid.") . "</span>";
                        $sess->ip_filter_value = $_POST['system_notification_filter'];
                    }
                } else {
                    $sess->ip_filter_error = "<span class=\"error\">" . $lang->__("One or more of the 'filtered' IP addresses was not valid.") . "</span>";
                    $sess->ip_filter_value = $_POST['system_notification_filter'];
                }
            // Check regular IP addresses.
            } else if (preg_match('/\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b/', (string)$ip) == 0) {
                $sess->ip_filter_error = "<span class=\"error\">" . $lang->__("One or more of the 'filtered' IP addresses was not valid.") . "</span>";
                $sess->ip_filter_value = $_POST['system_notification_filter'];
            }
        }
    }

    // If an IP error was found, return to the configuration page.
    if (isset($sess->ip_filter_error)) {
        header('Location: ' . BASE_PATH . SYS_PATH . '/system/configuration.php');
    } else {
        $config->findById('system_notification_filter');
        $config->value = implode(',', array_unique($ip_filter));
        $config->save();

        $config->findById('system_pagination_limit');
        $config->value = (is_numeric($_POST['system_pagination_limit'])) ? round(abs($_POST['system_pagination_limit'])) : '0';
        $config->save();

        $config->findById('system_pagination_range');
        $config->value = (is_numeric($_POST['system_pagination_range'])) ? round(abs($_POST['system_pagination_range'])) : '0';
        $config->save();

        $config->findById('default_editor');
        $config->value = $_POST['default_editor'];
        $config->save();

        $config->findById('default_system_template');
        $config->value = $_POST['default_system_template'];
        $config->save();

        $config->findById('default_language');
        $oldLang = $config->value;
        $config->value = $_POST['default_language'];
        $config->save();

        if (is_writable('../../config.php')) {
            $cfgFile = new Moc10_File('../../config.php');
            $cfgSettings = $cfgFile->read();
            $cfgSettings = str_replace("'MOC10_LANG', '" . $oldLang . "'", "'MOC10_LANG', '" . $_POST['default_language'] . "'", $cfgSettings);
            $cfgFile->write($cfgSettings);
        }

        $lg = new Phire_Language($_POST['default_language']);
        $sess->last_login = $lg->__('Never');

        include_once './server.check.php';

        header('Location: ' . BASE_PATH . SYS_PATH . '/system/configuration.php?action=saved');
    }

// Else throw a exception/error.
} catch (Exception $e) {

    include_once substr(BASE_PATH . SYS_PATH, 1) . '/core/process/init.php';
    include_once substr(BASE_PATH . SYS_PATH, 1) . '/core/includes/error.header.php';
    print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 0 0;\">" . $e->getMessage() . "</p>\n");
    include_once substr(BASE_PATH . SYS_PATH, 1) . '/core/includes/footer.php';

}

?>
